LexerBuilder

Struct LexerBuilder 

pub struct LexerBuilder<'s, TokenType> {
    pub actions: Vec<LexAction<'s, TokenType>>,
}
Struct used to generate a Lexer

It can either be initialised with an array of LexActions, or using the push method(recommended).

Fields

actions: Vec<LexAction<'s, TokenType>>

List of all tokens including conversions used by the resulting Lexer

Implementations

Source

impl<'s, TokenType> LexerBuilder<'s, TokenType>

pub fn new() -> Self

Returns an empty LexerBuilder

pub fn push( &mut self, token: &'s str, action: fn(&str) -> TokenType, ) -> &mut Self

Adds a new token to the LexerBuilder

token is the regex representation of the string
action is a method converting the &str representation of the token to a Token

pub fn build(&self) -> Lexer<TokenType>

Builds a new Lexer from the Actions configured in the Builder