pub struct LexerBuilder<'s, TokenType> {
pub actions: Vec<LexAction<'s, TokenType>>,
}Expand description
Struct used to generate a Lexer
It can either be initialised with an array of LexActions, or using the push method(recommended).
Fields
actions: Vec<LexAction<'s, TokenType>>List of all tokens including conversions used by the resulting Lexer
Implementations
Sourceimpl<'s, TokenType> LexerBuilder<'s, TokenType>
impl<'s, TokenType> LexerBuilder<'s, TokenType>